@@ -43,6 +43,7 @@ AbstractAccount::AbstractAccount(const QString &instanceUri, QObject *parent)
                                  i18n("M4V video (*.m4v)"),
                                  i18n("QuickTime video (*.mov)"),
                                  i18n("All files (*)")})
+    , m_maxCharactersPerOption(50)
 {
     // Test code uses a blank instance URI
     if (!AccountManager::instance().testMode()) {
@@ -96,6 +97,11 @@ size_t AbstractAccount::maxPollOptions() const
     return m_maxPollOptions;
 }
 
+size_t AbstractAccount::maxCharactersPerOption() const
+{
+    return m_maxCharactersPerOption;
+}
+
 bool AbstractAccount::supportsLocalVisibility() const
 {
     return m_supportsLocalVisibility;
@@ -193,6 +199,7 @@ void AbstractAccount::registerAccount(const QString &username,
                                       const QString &password,
                                       bool agreement,
                                       const QString &locale,
+                                      const QDate &dateOfBirth,
                                       const QString &reason)
 {
     // get an app-level access token, obviously we don't have a user token yet.
@@ -204,7 +211,7 @@ void AbstractAccount::registerAccount(const QString &username,
     q.addQueryItem(QStringLiteral("grant_type"), QStringLiteral("client_credentials"));
     q.addQueryItem(QStringLiteral("scope"), QStringLiteral("write"));
 
-    post(tokenUrl, q, false, this, [this, username, email, password, agreement, locale, reason](QNetworkReply *reply) {
+    post(tokenUrl, q, false, this, [this, username, email, password, agreement, locale, reason, dateOfBirth](QNetworkReply *reply) {
         auto data = reply->readAll();
         auto doc = QJsonDocument::fromJson(data);
 
@@ -218,6 +225,7 @@ void AbstractAccount::registerAccount(const QString &username,
             {QStringLiteral("agreement"), agreement ? QStringLiteral("1") : QStringLiteral("0")},
             {QStringLiteral("locale"), locale},
             {QStringLiteral("reason"), reason},
+            {QStringLiteral("date_of_birth"), dateOfBirth.toString(Qt::DateFormat::ISODate)},
         };
 
         post(
@@ -232,6 +240,7 @@ void AbstractAccount::registerAccount(const QString &username,
                 if (doc.object().contains("access_token"_L1)) {
                     setUsername(username);
                     setAccessToken(doc["access_token"_L1].toString());
+                    validateToken();
                 }
             },
             [this](QNetworkReply *reply) {
@@ -338,7 +347,6 @@ void AbstractAccount::setAccessToken(const QString &token)
 {
     m_token = token;
     QMessageFilterContainer::self()->insert(m_token, QStringLiteral("ACCESS_TOKEN"));
-    validateToken();
 }
 
 void AbstractAccount::setInstanceUri(const QString &instance_uri)
@@ -371,6 +379,7 @@ void AbstractAccount::setToken(const QString &authcode)
         auto doc = QJsonDocument::fromJson(data);
 
         setAccessToken(doc.object()["access_token"_L1].toString());
+        validateToken();
     });
 }
 
@@ -461,6 +470,14 @@ void AbstractAccount::fetchInstanceMetadata()
 
             const auto obj = doc.object();
 
+            if (obj.contains("api_versions"_L1)) {
+                const auto apiVersions = obj["api_versions"_L1].toObject();
+                for (const auto &api : apiVersions.keys()) {
+                    const auto version = apiVersions[api].toInt();
+                    m_supportedApiVersions[api] = version;
+                }
+            }
+
             if (obj.contains("configuration"_L1)) {
                 const auto configObj = obj["configuration"_L1].toObject();
 
@@ -495,6 +512,10 @@ void AbstractAccount::fetchInstanceMetadata()
                         m_attachmentFilterStrings.push_back(i18n("All files (*)"));
                     }
                 }
+
+                if (configObj.contains("vapid"_L1)) {
+                    m_instanceVapidPublicKey = configObj["vapid"_L1]["public_key"_L1].toString();
+                }
             }
 
             // Pleroma/Akkoma may report maximum post characters here, instead
@@ -510,6 +531,7 @@ void AbstractAccount::fetchInstanceMetadata()
             // Other instance of poll options
             if (obj.contains("polls"_L1)) {
                 m_maxPollOptions = obj["polls"_L1].toObject()["max_options"_L1].toInt();
+                m_maxCharactersPerOption = obj["polls"_L1].toObject()["max_characters_per_option"_L1].toInt();
             }
 
             if (obj.contains("registrations"_L1)) {
@@ -878,4 +900,12 @@ bool AbstractAccount::isFavoriteList(const QString &id)
     return config()->favoriteListIds().contains(id);
 }
 
+bool AbstractAccount::supportsApiVersion(const QString &api, int minimumVersion)
+{
+    if (m_supportedApiVersions.contains(api)) {
+        return m_supportedApiVersions[api] >= minimumVersion;
+    }
+    return false;
+}
+
 #include "moc_abstractaccount.cpp"
